#include <Wire.h>
#include <TimerOne.h>
#include <uSonic.h>

#define       NEW_ADRESS    0xF6

int Adress;

// Send a command at each adress
// return the adress of the first module found (ACK has been received)
// return -1 if no module are found
int US_SearchAdress()
{
  int Adress=0;                                          
  int Ret;
  do
  {
    Wire.beginTransmission(Adress>>1);
    Wire.send(0x5D);
    Ret=Wire.endTransmission();
    Adress+=2;
    if (Adress>256) return -1;                            // No module found
  }
  while (Ret!=0);
  return Adress-2;
}




void setup()
{
  Serial.begin(115200);                                    // Initialize serial link
  Serial.println ("::: Reprogram US I2C adress :::");      // Print welcome message !
  Timer1.initialize();

  // Initialize transmission
  
  US_Init();                                            // Start transmission
  
  
  // Look for current adress
  
  Adress=US_SearchAdress(); 
  if (Adress<0)
  {
      Serial.println ("Module not found");
      while (1);
  }  
  Serial.print ("Module founded: Adress=0h");
  Serial.println (Adress,HEX);
  delay (10);
 
 
  // Get version number
 
  Serial.print("Version = ");
  Serial.println (US_GetVersion(Adress),DEC);
  delay (10);
  
  
  // Get software revision
 
  Serial.print("Software revision = ");
  Serial.println (US_GetSoftwareRevision(Adress),DEC);


  // Get range
  
  if (US_RequestMesurement(Adress)!=0)
    Serial.println ("ERROR while requesting mesurement");
  Serial.print("Range (cm) = ");
  
  delay(70);
  Serial.println (US_GetRange(Adress),DEC);


  // Change adress

  delay (100);
  if (US_ChangeAdress(Adress,NEW_ADRESS)!=0)
    Serial.println ("Error while changing adress");
  else
    Serial.println ("Successfully change adress !");
    
    
  // Check new adress
    
  Adress=US_SearchAdress();   
  if (Adress<0)
  {
      Serial.println ("Module not found");
      while (1);
  }  
  Serial.print ("Module founded : New Adress=0h");
  Serial.println (Adress,HEX);
  delay (10);   
}



void loop()
{
  if (Serial.available())
  {
    Serial.read();                                        // Flush one character from the buffer
   
    
  
    if (US_RequestMesurement(Adress)!=0)
      Serial.println ("ERROR while requesting mesurement");
    Serial.print("Range (cm) = ");
  
    Timer1.restart();
    while (US_GetSoftwareRevision(Adress)<0);
    long int Duration=Timer1.read();
    Serial.println (US_GetRange(Adress),DEC);
    Serial.print ("Elapsed time : ");
    Serial.print (Duration,DEC);
    Serial.println (" us");
  }
}
