#include <TimerOne.h>
#include <batteryCheck.h>
#include <inclinometer.h>
#include <motors.h>
#include <dynamixel.h>
#include <dynamixelUse.h>

// Constants

#define BUFFER_SIZE  128                // Buffer size (Transmit and receive)
#define PUSH_BUTTON  10                 // ID of the pin connected to the push button
#define SERVO_ID     6                  // ID of the servomotor



// Functions


bool CheckCode(char *Buffer,const char *Code,int Lenght);     // Check if the string is valid and first characters are equal to the code
void ResetBufferTx();                                     // Reset transmission buffer
void AddCharBufferTx(char Val);                           // Add an integer in the tramsission buffer
void AddIntBufferTx(int Val);                             // Add an integer in the tramsission buffer
void AddFloatBufferTx(float Val);                         // Add an integer in the tramsission buffer
void SendBufferTx();                                      // Finalize and send the transmission buffer



// Global variables

char       BfrRx[BUFFER_SIZE];          // Buffer for data received from the PC
char       BfrTx[BUFFER_SIZE];          // Buffer with data to send to the PC
int        IndBfrRx=0;                  // Current index of the received buffer
int        IndBfrTx=0;                  // Current index of the transmit buffer
Dynamixel  ServoLidar;                  // Create the object for controlling the servomoteur




void setup()
{
  // Initialize UARTs
  pinMode(PUSH_BUTTON, INPUT);             // For button (configured as imput)
  digitalWrite (PUSH_BUTTON,HIGH);
  Serial.begin (115200);                   // For communication with the PC
  Serial1.begin(115200);                   // For communication with the left motor
  Serial2.begin(115200);                   // For communication with the right motor

  int Err=0;                               // Error code     | Servomotor
  
  
  // Initialize Servomotor connection
  Err=!ServoLidar.SetGoalPosition(SERVO_ID,512);
  
  Serial.println (ServoLidar.GetPresentPosition(SERVO_ID));

  // Initialize motors
  Err=Err | (!ResetLeft() << 1);
  Err=Err | (!ResetRight() << 2); 
  

  if (Err==0)
    Serial.print("OK\n");
  else
  {
    Serial.print("ER");
    Serial.print(Err,DEC);
  }

  for (int i=200;i<800;i+=10)
  {
    ServoLidar.SetGoalPosition(SERVO_ID,i);
//    Serial.println(i);
    delay (25);
  }

  while (1);
}



void loop()
{
  // Check if a new charactere has been received from the PC
  if (Serial.available())
  {
    // Add the character to the buffer
    BfrRx[IndBfrRx++]=Serial.read();
    


    if (IndBfrRx==3)
    {
/*
      // Request batteries voltage      
      if (CheckCode(BfrRx,"BU",IndBfrRx)                                        // BA : Batteries voltage
      {
        ResetBufferTx();
        AddIntBufferTx(Battery1State_mV());
        AddIntBufferTx(Battery2State_mV());    
        SendBufferTx();
        IndBfrRx=0;   
      }    
    }
      
      
      
      
      
      
      
      // Request inclinometer data
      if (!strcmp (BfrRx,"IN\n"))                                          // IN : inclinometer
      {
        ResetBufferTx();
        AddFloatBufferTx(GetRoll());
        AddFloatBufferTx(GetPitch());    
        SendBufferTx();
        IndBfrRx=0;   
      }    
     
     
     
     // Request push button state
      if (CheckCode(BfrRx,"BU",IndBfrRx))                                   // BU : Push button
      {
        ResetBufferTx();
        AddCharBufferTx(digitalRead(PUSH_BUTTON));   
        SendBufferTx();
        IndBfrRx=0;   
      }    
     
     
      // Set servo position
      if (BfrRx[0]=='S' && BfrRx[1]=='E' && BfrRx[4]=='\n' && BfrRx[5]==0)  // SE : Servomotor
      {
        Serial.print ("Ici");
        IndBfrRx=0;   
      }    
     
     */
     
     
     
     IndBfrRx=0;   
    }       
  }
}




/**************************************/
/*        Transmission functions      */
/**************************************/



bool CheckCode(char *Buffer,const char *Code,int Lenght)
{
  if (Buffer[0]==Code[0] && Buffer[1]==Code[1])
  {
    int Sum=0;
    for (int i=0;i<Lenght;i++) Sum+=Buffer[0];
    Sum%=0xFF;

    return true;
  }
  else 
    return false;
}


// Reset the transmission buffer
void ResetBufferTx()
{
//  for (int i=0;i<BUFFER_SIZE;i++)
//    BfrTx[i]=0;
  IndBfrTx=0;
}

// Add an integer in the buffer
void AddCharBufferTx(char Val)
{
  unsigned char* Pt=(unsigned char*)&Val;
  BfrTx[IndBfrTx++]=*Pt;
}

// Add an integer in the buffer
void AddIntBufferTx(int Val)
{
  unsigned char* Pt=(unsigned char*)&Val;
  BfrTx[IndBfrTx++]=*Pt;
  BfrTx[IndBfrTx++]=*(Pt+1);
}

// Add an integer in the buffer
void AddFloatBufferTx(float Val)
{
  unsigned char* Pt=(unsigned char*)&Val;
  BfrTx[IndBfrTx++]=*Pt;
  BfrTx[IndBfrTx++]=*(Pt+1);
  BfrTx[IndBfrTx++]=*(Pt+2);
  BfrTx[IndBfrTx++]=*(Pt+3);  
}


// Finalize and send the transmission buffer
void SendBufferTx()
{
   BfrTx[IndBfrTx++]='C';
   BfrTx[IndBfrTx++]=10;
   for (int i=0;i<IndBfrTx;i++)
     Serial.print(BfrTx[i]);   
}
