/**\file batteryCheck.cpp
 * \brief These functions check the battery states by returning the battery voltage.
 * \details See also : \n \n batteryCheck.h \n The header File Reference. \n \n
 * \link BCheck Batteries Check \endlink \n For functions descriptions.*/


/* Reads the voltage divider to calculate a battery voltage */

#include "batteryCheck.h"


int BatMon1Pin = 2;							// Input pin for the divider
int BatMon2Pin = 3;
int Bat1val = 0;							// Variable for the A/D value
int Bat2val = 0; 
float Pin2Voltage = 0;						// Variable to hold the calculated voltage
float Pin3Voltage = 0;


float Ratio = 4.86;							// Change this to match the MEASURED ratio of the circuit


// Get the state (voltage) of the first battery (in Volts)
double Battery1State_V() 
{  
#ifdef __DEBUG__BC__
	Serial.println("Getting battery 1 voltage...");
#endif

	double Battery1Voltage = 0;
	Bat1val = analogRead(BatMon1Pin);		// Read the voltage on the divider  
 
	Pin2Voltage = Bat1val * 0.0048828125;		//  Calculate the voltage on the A/D pin
											//  A reading of 1 for the A/D = 0.0048mV
											//  If we multiply the A/D reading by 0.00488 then 
											//  We get the voltage on the pin.                                  
                                    
                                    
  
	Battery1Voltage = Pin2Voltage * Ratio;	//  Use the ratio calculated for the voltage divider
											//  To calculate the battery voltage
	return (Battery1Voltage); 
}    


// Get the state (voltage) of the second battery (in Volts)
double Battery2State_V() 
{         
#ifdef __DEBUG__BC__
	Serial.println("Getting battery 2 voltage...");
#endif

	double Battery2Voltage = 0;
	Bat2val = analogRead(BatMon2Pin);		// Read the voltage on the divider  
  
	Pin3Voltage = Bat2val * 0.0048828125;		//  Calculate the voltage on the A/D pin
											//  A reading of 1 for the A/D = 0.0048mV
											//  If we multiply the A/D reading by 0.00488 then 
											//  We get the voltage on the pin.                                  
                                    

	Battery2Voltage = Pin3Voltage * Ratio; 

	return (Battery2Voltage);				//  To calculate the battery voltage                                       
}

// Get the state (voltage) of the first battery (in millivolts)
unsigned int Battery1State_mV() 
{  
	
#ifdef __DEBUG__BC__
	Serial.println("Getting battery 1 voltage...");
#endif
	double Battery1Voltage = 0;
	Bat1val = analogRead(BatMon1Pin);		// Read the voltage on the divider  
 
	Pin2Voltage = Bat1val * 0.0048828125;		//  Calculate the voltage on the A/D pin
											//  A reading of 1 for the A/D = 0.0048mV
											//  If we multiply the A/D reading by 0.00488 then 
											//  We get the voltage on the pin.                                  
                                    
                                    
  
	Battery1Voltage = Pin2Voltage * Ratio;	//  Use the ratio calculated for the voltage divider
											//  To calculate the battery voltage
	return (Battery1Voltage*1000.0); 
}    


// Get the state (voltage) of the second battery (in millivolts)
unsigned int Battery2State_mV() 
{         
#ifdef __DEBUG__BC__
	Serial.println("Getting battery 2 voltage...");
#endif

	double Battery2Voltage = 0;
	Bat2val = analogRead(BatMon2Pin);		// Read the voltage on the divider  
  
	Pin3Voltage = Bat2val * 0.0048828125;		//  Calculate the voltage on the A/D pin
											//  A reading of 1 for the A/D = 0.0048mV
											//  If we multiply the A/D reading by 0.00488 then 
											//  We get the voltage on the pin.                                  
                                    

	Battery2Voltage = Pin3Voltage * Ratio; 

	return (Battery2Voltage*1000.0);				//  To calculate the battery voltage                                       
}
