/**\file batteryCheck.h
 * \brief These functions check the battery states by returning the battery voltage.
 * \details See also : \n \n batteryCheck.cpp \n The C++ File Reference of this header. \n \n
 * \link BCheck Batteries Check \endlink \n For functions descriptions.*/

#ifndef  batteryCheck_h
#define  batteryCheck_h


#include <WProgram.h>
#include <../Wire/Wire.h>


/*
  batteryCheck.h - Library for reading value from the inclinometer
  from Vicatronic (Lipoly-Accu Robbe)


  Copyright (c) 2011 David Drissi.  All right reserved.
  Property of the University of Angers.

  Contact : philippe.lucidarme@univ-angers.fr

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.  
*/


/*!\defgroup BCheck Batteries Check
 * \brief Additional documentation for group 'Batteries Check'. This file contains functions to check batteries state. 
 * \details See also : \n \n batteryCheck.h \n Here is a link to the Header File Reference. \n
 *  batteryCheck.cpp \n Here is a link to the C++ File Reference. 
 *  @{ */

/*! Get the state (voltage) of the first battery.
 * \return a double, the voltage of the first battery in V.*/
double	Battery1State_V();

/*! Get the state (voltage) of the second battery.
 * \return a double, the voltage of the second battery in V.*/
double	Battery2State_V();

/*! Get the state (voltage) of the first battery.
 * \return a unsigned int, the voltage of the first battery in mV.*/
unsigned int	Battery1State_mV();

/*! Get the state (voltage) of the second battery.
 * \return a unsigned int, the voltage of the second battery in mV.*/
unsigned int	Battery2State_mV();

/*! @}*/

#endif







