/**\file inclinometer.h 
 * \brief All tools to get inclinometer value on each axis.
 * \details See also : \n \n inclinometer.cpp \n The C++ File Reference of this header.*/

#ifndef inclinometer_h
#define inclinometer_h


#include <WProgram.h>


/*
  inclinometer.h - Library for reading value from the inclinometer
  from Vicatronic (QG40 DIS international sensor)


  Copyright (c) 2011 David Drissi.  All right reserved.
  Property of the University of Angers.

  Contact : philippe.lucidarme@univ-angers.fr

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.  
*/

/*! \defgroup Inclinometer Inclinometer
 *  \brief Additional documentation for group 'Inclinometer'. This file contains functions to get inclinaison value around axis X and Y.
 *  \details inclinometer.h \n Here is a link to the Header File Reference.\n 
 *  inclinometer.cpp \n Here is a link to the C++ File Reference.
 *  @{ */
 
/*! A member function which returns the roll.
 *  \return a double that represents the value of the tilt (in degrees) on the roll axis (around Y).*/

// Returns tilt of the robot around Y
// Angle along the Y axis
float GetRoll();

/*! A member function which returns the pitch.
 * \return a double that represents the value of the tilt (in degrees) on the pitch axis (around X).*/

// Returns tilt of the robot around X
// Angle along the X axis
float GetPitch();

/*!
 * @}
 */

#endif

