/**\file pcf8574.h
 * \brief Controls leds and buttons using a port expander.
 * \detail See also : \n \npcf8574.cpp \n The C++ File Reference.*/



#ifndef pcf8574_h

#define pcf8574_h

#include <WProgram.h>
#include <Wire.h>

/*! The actual address for the pcf8574 B01001110 but because Arduino wire uses 7 bits, we take the lowest bit off and put it in the highest position the address becomes B00100111. When this is done the last 3 bits are the address bits set using the jumpers on the board ,1 is pulled high on the board . */
#define expander B00100111 
#define ON  1
#define OFF 0    

/*!\defgroup pcf8574 Leds and buttons
 * \brief Additional documentation for group 'Leds and buttons'. This file contains functions to control leds and buttons using a port expander. 
 * \details See also : \n \n pcf8574.h \n Here is a link to the Header File Reference. \n
 *  pcf8574.cpp \n Here is a link to the C++ File Reference. 
 *  @{ */

/*! Sets the pins to high or low.
 * \param _data Data to write. Write bit is 0 and read bit is 1.
 * \return no return.*/
void ExpanderWrite(unsigned char _data ) ; 

/*! Reads the pins on the port expander.
 * \param TimeOut Defines the length of the time out during the reception.
 * \return an int of data.*/
int ExpanderRead(int TimeOut) ;  

/*! Reads the state of button 1.
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error and -5 means time out occurence.*/
char Button1();

/*! Reads the state of button 2.
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error and -5 means time out occurence.*/
char Button2();

/*! Reads the state of button 3.
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error and -5 means time out occurence.*/
char Button3();

/*! Reads the state of button 4.
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error and -5 means time out occurence.*/
char Button4();

/*! Sets the state of the led 1.
 * \param state 1 is ON and 0 is OFF. 
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error.*/
char Led1(char state );

/*! Sets the state of the led 2.
 * \param state 1 is ON and 0 is OFF. 
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error.*/
char Led2(char state);

/*! Sets the state of the led 3.
 * \param state 1 is ON and 0 is OFF. 
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error.*/
char Led3(char state);

/*! Sets the state of the led 4.
 * \param state 1 is ON and 0 is OFF. 
 * \return 1 means button is pressed, 0 button is not pressed, from -1 to -4 transmission error.*/
char Led4(char state);

/*! Interrupt function for reception mode of the port expander.
 * \return no return.*/
void ISR_Interrupt();

#endif
