/**\file uSonic.h 
 * \brief A function  that   receives   distances returned  by the ultrasonic sensors.
 * \details uSonic.cpp \n Here is the C++ File Reference of this header.*/

#ifndef __uSonic_h__
#define __uSonic_h__


#include <WProgram.h>
#include <../Wire/Wire.h>


// #define 		__DEBUG__US__

/*
  uSonic.h - Library for reading value from each ultrasonic sensor
  from Lextronic (SFR02 Robot-Electronics)


  Copyright (c) 2011 David Drissi.  All right reserved.
  Property of the University of Angers.

  Contact : philippe.lucidarme@univ-angers.fr

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.  
*/

/*! The address of the first sensor */ 
#define srfAddress 0xF9
/*! The address of the second sensor */
#define srAddress 0xF0                
   
            
/*!\defgroup USSensors Ultra Sonic Sensors
 * \brief Additional documentation for group 'Ultra Sonic Sensors'. This file contains functions to get distance relieved by ultrasonic sensors. 
 * \details See also : \n \n uSonic.h \n Here is a link to the Header File Reference. \n
 *  uSonic.cpp \n Here is a link to the C++ File Reference. 
 *  @{ */

 
 
// US_Init
// Initialize IC line
 void US_Init();

// US_RequestMesurement
// Send the command for requesting a mesurement in centimeters
// Parameters : Adress = adress of the sensor 
// Return :		0 = success
//				-1 = failled to send command
char US_RequestMesurement(byte Adress);
 
// US_GetRange
// Get distance mesured by the sensor in centimeters
// US_RequestMesurement must has be sent previously (wait 70ms before reading result)
// Parameters : Adress = adress of the sensor 
// return :		>0 : Distance in centimeters
//				-1 : failled to send data to the module
//				-2 : failled to receive data from the module
int US_GetRange(byte Adress);                     

// US_GetVersion
// Read and return the version number of the sensor with located at adress
// return : 	>=0 version number
//				-1 : failled to send command
//				-2 : data not received successfully
int 	US_GetVersion(byte Adress);

// US_GetSoftwareRevision
// Read and return the software revision of the sensor with located at adress
// return : 	>=0 Software revision
//				-1 : failled to send command
//				-2 : data not received successfully
int US_GetSoftwareRevision(byte Adress);


// US_ChangeAdress
// Change IC adress of one module
// ONLY ONE MODULE MUST BE CONNECTED TO THE LINE
// Old is the current adress of the module
// New is the new adress of the module after the change
// Possible adresses for SFR02 are 0xE0, 0xE2, 0xE4, 0xE6, 0xE8, 0xEA, 0xEC, 0xEE, 0xF0, 0xF2, 0xF4, 0xF6, 0xF8, 0xFA, 0xFC, 0xFE
// Return :  0 success
//           -1 if first frame is not successfully sent
//           -2 if second frame is not successfully sent
//           -3 if third frame is not successfully sent
//           -4 if fourth frame is not successfully sent
int US_ChangeAdress(byte Old,byte New);
 
#endif




